@@ -293,7 +293,7 @@ namespace giac {
     int unknowns=0;
     for (;vit!=vitend;++vit){
       if (vit->mult>1)
-	break;
+	break; // return false might be more appropriate here
       unknowns += int(vit->fact.coord.size())-1; // lcoeff is known
     }
     if (unknowns>=giacmax(5,pcur.lexsorted_degree()/2) || unknowns==0)
@@ -320,6 +320,8 @@ namespace giac {
       vector< monomial<gen> >::const_iterator it=fact.coord.begin(),itend=fact.coord.end();
       gen Pi=lc*pow(mainvar,it->index.front());
       for (++it;it!=itend;++it){
+	if (pos>=la.size()) 
+	  return false;
 	Pi += la[pos]*pow(mainvar,it->index.front());
 	++pos;
       }
@@ -353,7 +355,7 @@ namespace giac {
       lvar(linear,indet);
       indet=vecteur(indet.begin()+lv.size(),indet.end());
       vecteur sols=linsolve(linear,indet,context0);
-      if (sols.size()!=indet.size() || is_undef(sols))
+      if (sols.size()!=indet.size() || is_undef(sols) || sols.empty())
 	return false;
       la_val=subst(la_val,indet,sols,false,context0);
       gen tmp=recursive_normal(subst(syst,indet,sols,false,context0),context0);
@@ -822,8 +824,8 @@ namespace giac {
 	  peval_xk_xn_zero(jt->fact,2,tmp); // should only depend on x2
 	  if (Tis_constant(tmp))
 	    constante=constante*pow(jt->fact,jt->mult);
-	  else 
-	    flcoeff0.push_back(tmp);
+	  //else 
+	  flcoeff0.push_back(tmp);
 	} // flcoeff0 contains the list of factors of lcoeff(pcur) evaled at 0
 	F0it=fx1x2.begin();
 	F0itend=fx1x2.end();
@@ -1570,7 +1572,7 @@ namespace giac {
     return heugcd_psrgcd_ezgcd_modgcd(args,2,contextptr);
   }
   static const char _ezgcd_s []="ezgcd";
-  static define_unary_function_eval (__ezgcd,&giac::_ezgcd,_ezgcd_s);
+  static define_unary_function_eval (__ezgcd,&_ezgcd,_ezgcd_s);
   define_unary_function_ptr5( at_ezgcd ,alias_at_ezgcd,&__ezgcd,0,true);
   
   gen _modgcd(const gen & args,GIAC_CONTEXT){
@@ -1580,7 +1582,7 @@ namespace giac {
     return heugcd_psrgcd_ezgcd_modgcd(args,3,contextptr);
   }
   static const char _modgcd_s []="modgcd";
-  static define_unary_function_eval (__modgcd,&giac::_modgcd,_modgcd_s);
+  static define_unary_function_eval (__modgcd,&_modgcd,_modgcd_s);
   define_unary_function_ptr5( at_modgcd ,alias_at_modgcd,&__modgcd,0,true);
   
   gen _heugcd(const gen & args,GIAC_CONTEXT){
@@ -1590,7 +1592,7 @@ namespace giac {
     return heugcd_psrgcd_ezgcd_modgcd(args,0,contextptr);
   }
   static const char _heugcd_s []="heugcd";
-  static define_unary_function_eval (__heugcd,&giac::_heugcd,_heugcd_s);
+  static define_unary_function_eval (__heugcd,&_heugcd,_heugcd_s);
   define_unary_function_ptr5( at_heugcd ,alias_at_heugcd,&__heugcd,0,true);
 
   gen _psrgcd(const gen & args,GIAC_CONTEXT){
@@ -1600,7 +1602,7 @@ namespace giac {
     return heugcd_psrgcd_ezgcd_modgcd(args,1,contextptr);
   }
   static const char _psrgcd_s []="psrgcd";
-  static define_unary_function_eval (__psrgcd,&giac::_psrgcd,_psrgcd_s);
+  static define_unary_function_eval (__psrgcd,&_psrgcd,_psrgcd_s);
   define_unary_function_ptr5( at_psrgcd ,alias_at_psrgcd,&__psrgcd,0,true);
 
 
