@@ -337,6 +337,7 @@ namespace giac {
       return gendimerr(contextptr);
     if (args._VECTptr->back().type==_VECT)
       return _plus(gauss(args._VECTptr->front(),*(args._VECTptr->back()._VECTptr),contextptr),contextptr);
+    return _randNorm(args,contextptr);
     return symb_gauss(args);
   }
   static const char _gauss_s []="gauss";
@@ -414,15 +415,17 @@ namespace giac {
     if (is_undef(M))
       return undef;
     gen Mx,My,x(x__IDNT_e),y(y__IDNT_e),t(t__IDNT_e);
-    ck_parameter_x(contextptr);
-    ck_parameter_y(contextptr);
+    if (!contains(eq,x))
+      ck_parameter_x(contextptr);
+    if (!contains(eq,y))
+      ck_parameter_y(contextptr);
     ck_parameter_t(contextptr);
     reim(M,Mx,My,contextptr);
     gen eqM=_quo(makesequence(subst(eq,makevecteur(x,y),makevecteur(Mx+x,My+t*x),false,contextptr),x),contextptr);
     gen a,b;
     if (!is_linear_wrt(eqM,x,a,b,contextptr))
       return undef;
-    return M+(-b/a)*(1+cst_i);
+    return M+(-b/a)*(1+cst_i*t);
     vecteur res=solve(eqM,x,0,contextptr); // x in terms of t
     if (res.size()!=1)
       return undef;
@@ -435,8 +438,10 @@ namespace giac {
     if (is_undef(M))
       return vecteur(1,undef);
     gen Mx,My,x(x__IDNT_e),y(y__IDNT_e),t(t__IDNT_e);
-    ck_parameter_x(contextptr);
-    ck_parameter_y(contextptr);
+    if (!contains(eq,x))
+      ck_parameter_x(contextptr);
+    if (!contains(eq,y))
+      ck_parameter_y(contextptr);
     ck_parameter_t(contextptr);
     reim(M,Mx,My,contextptr);
     gen eqM=_quo(makesequence(subst(eq,makevecteur(x,y),makevecteur(Mx+x,My+t*x),false,contextptr),x),contextptr);
