@@ -205,11 +205,13 @@ namespace giac {
       of << '"' << output_quote(it->cmd_name) << '"' << ",";
       std::vector<localized_string> & blabla = it->blabla;
       sort(blabla.begin(),blabla.end());
-      int bs=int(blabla.size());
+      int blablapos=0;
       of << "{";
       for (int i=0;i<HELP_LANGUAGES;i++){
-	if (i<bs && i+1==blabla[i].language && equalposcomp(langv,i+1))
-	  of << '"' << output_quote(blabla[i].chaine) << '"' ;
+	if (i+1==blabla[blablapos].language && equalposcomp(langv,i+1)){
+	  of << '"' << output_quote(blabla[blablapos].chaine) << '"' ;
+	  blablapos++;
+	}
 	else
 	  of << 0 ;
 	if (i==HELP_LANGUAGES-1)
@@ -219,7 +221,7 @@ namespace giac {
       }
       of << "," << '"' << output_quote(it->syntax) << '"' << ',' ;
       std::vector<std::string> & examples = it->examples;
-      bs=int(examples.size());
+      int bs=int(examples.size());
       if (bs){
 	of << '"';
 	for (int i=0;i<bs;i++){
@@ -938,7 +940,7 @@ namespace giac {
 #else
 // __APPLE_CC__ == 5666 on Mac OS X 10.6, 5658 on geogebra build system OS X 10.8
 // should check __APPLE__ OS X version instead!
-#if ( defined(__MAC_OS_X_VERSION_MAX_ALLOWED)&&  __MAC_OS_X_VERSION_MAX_ALLOWED<  1080 ) || ( defined(__IPHONE_OS_VERSION_MAX_ALLOWED)&&  __IPHONE_OS_VERSION_MAX_ALLOWED<  60100 ) || defined(__OpenBSD__) || ( defined(__FreeBSD_version)&&  __FreeBSD_version<800501)
+#if ( defined(__MAC_OS_X_VERSION_MAX_ALLOWED)&&  __MAC_OS_X_VERSION_MAX_ALLOWED<  1080 ) || ( defined(__IPHONE_OS_VERSION_MAX_ALLOWED)&&  __IPHONE_OS_VERSION_MAX_ALLOWED<  60100 ) || ( defined(__OpenBSD__)&& OpenBSD<201905) || ( defined(__FreeBSD_version)&&  __FreeBSD_version<800501)
   static int dir_select (struct dirent *d){
 #else
   static int dir_select (const struct dirent *d){
