@@ -285,7 +285,8 @@ namespace giac {
 	    if(!((mys.feuille._VECTptr->back()==plus_one_half))){
 	      if ((mys.feuille._VECTptr->front().type==_INT_)||(mys.feuille._VECTptr->front().type==_ZINT)){
 	        if  (is_positive(mys.feuille._VECTptr->front(),contextptr))
-	          s += "<mo>&times;</mo>";// F.H: 2*2^n et 22^n, 2*2^(1/7)  mais pas 2*sqrt(2). 
+		  if (s.size()<16 || s.substr(s.size()-16,16)!="<mo>&times;</mo>")
+		    s += "<mo>&times;</mo>";// F.H: 2*2^n et 22^n, 2*2^(1/7)  mais pas 2*sqrt(2). 
 	      }
 	    } 
 	}
@@ -1102,13 +1103,19 @@ namespace giac {
     }
     else
       s= "<line vector-effect=\"non-scaling-stroke\" stroke-width=\""+print_INT_(attr.width);
+    gen reB,imB;
+    reim(B,reB,imB,contextptr);
     s = s+"\" stroke=\""+color_string(attr)+"\" x1=\""
       + re(A,contextptr).print(contextptr)+"\" y1=\""
       + im(A,contextptr).print(contextptr)+"\" x2=\""
-      + re(B,contextptr).print(contextptr)+"\" y2=\""
-      + im(B,contextptr).print(contextptr)+"\"/>\n";
+      + reB.print(contextptr)+"\" y2=\""
+      + imB.print(contextptr)+"\"/>\n";
     //CERR << s << endl;
-    s = s+svg_text(B,legende,attr,xmin,xmax,ymin,ymax,contextptr);
+    if (is_positive((reB-xmax)*(reB-xmin),contextptr) ||
+	is_positive((imB-ymax)*(imB-ymin),contextptr))
+      s = s+svg_text((A+B)/2,legende,attr,xmin,xmax,ymin,ymax,contextptr);
+    else
+      s = s+svg_text(B,legende,attr,xmin,xmax,ymin,ymax,contextptr);
     return s;
   }
 
@@ -1187,7 +1194,7 @@ namespace giac {
 	}
       }
       if (attr.type_line>4){
-	reverse(v.begin(),v.end());
+	//reverse(v.begin(),v.end());
 	s=svg_vecteur(v[v.size()/2],v[v.size()/2+1],attr,"",xmin,xmax,ymin,ymax,contextptr);
       }
       return s=s+svg_bezier_curve(v,attr,legende,xmin,xmax,ymin,ymax,contextptr);
