@@ -178,15 +178,30 @@ namespace giac {
   static define_unary_function_eval (__sizes,&_sizes,_sizes_s);
   define_unary_function_ptr5( at_sizes ,alias_at_sizes,&__sizes,0,true);
 
+  longlong lcm(int a,int b){
+    int d=gcd(a,b);
+    return (a/d)*longlong(b);
+  }
+
+  int lcm(const vector<int> & v){
+    vector<int>::const_iterator it=v.begin(),itend=v.end();
+    if (itend==it) return 0;
+    if (itend==it+1) return *it;
+    int r=lcm(*it,*(it+1));
+    for (it+=2;it<itend;++it)
+      r=lcm(r,*it);
+    return r;
+  }
+
   static int cyclesorder(const vector< vector<int> > & v,GIAC_CONTEXT){
     vector<int> ss;
     ss=sizes(v);   
-    return(_lcm(vector_int_2_vecteur(ss,contextptr),contextptr).val);
+    return lcm(ss);
   } 
   static int permuorder(const vector<int> & p,GIAC_CONTEXT){
     vector< vector<int> > c;  
     c=permu2cycles(p);
-    return(_lcm(vector_int_2_vecteur(sizes(c),contextptr),contextptr).val);
+    return lcm(sizes(c));
   }
 
   gen _permuorder(const gen & args,GIAC_CONTEXT){
@@ -302,7 +317,7 @@ namespace giac {
       return w;
     }
     gen n=args;
-    if (!is_integral(n) || n.type!=_INT_) 
+    if (!is_integral(n) || n.type!=_INT_ || n.val<=0) 
       return gensizeerr(contextptr);
     return vector_int_2_vecteur(randperm(n.val),contextptr);
   }
@@ -359,22 +374,21 @@ namespace giac {
     int n1;
     n1=int(c.size());
     //vector<int> p;
-    vector<int> c2(n1);
-    c1=c2;
+    c1.resize(n1);
+    int b=array_start(contextptr);
     for (int j=0;j<n1;j++){
-      if (array_start(contextptr))//xcas_mode(contextptr)>0 || abs_calc_mode(contextptr)==38) 
-	c1[j]=c[j].val-1; 
-      else 
-	c1[j]=c[j].val;
+      int tmp=c[j].val-b;
+      if (tmp<0) 
+	return false;
+      c1[j]=tmp;
     }   
-    for (int k=0;k<n1-1;k++) {
-      int ck=c1[k];
-      if (ck<0) {return(false);}
-      for (int j=k+1;j<n1;j++){
-	if (ck==c1[j]) {return (false);}
-      }
+    vector<int> c2(c1);
+    sort(c2.begin(),c2.end());
+    for (int k=1;k<n1;k++) {
+      if (c2[k]==c2[k-1])
+	return false;
     }
-    return (true);
+    return true;
   } 
   gen _is_cycle(const gen & args,GIAC_CONTEXT){
     if ( args.type==_STRNG && args.subtype==-1) return  args;
@@ -1692,6 +1706,22 @@ namespace giac {
       return gentypeerr(contextptr);
     vecteur v(*args._VECTptr);
     gen g1=v.front(),g2=v.back();
+    if (g1.type==_STRNG && g2.type==_STRNG){ // Python "Ceci est une phrase".split(" ")
+      if (g2._STRNGptr->empty())
+	return gendimerr(contextptr);
+      vecteur res;
+      int pos=0,ss=g1._STRNGptr->size();
+      for (;pos<ss;){
+	int npos=g1._STRNGptr->find(*g2._STRNGptr,pos);
+	if (npos<0 || npos>=ss)
+	  break;
+	res.push_back(string2gen(g1._STRNGptr->substr(pos,npos-pos),false));
+	pos=npos+g2._STRNGptr->size();
+      }
+      if (pos<ss)
+	res.push_back(string2gen(g1._STRNGptr->substr(pos,ss-pos),false));
+      return res;
+    }
     if (g2.type!=_VECT)
       return gentypeerr(contextptr);
     vecteur v2(*g2._VECTptr);
@@ -1724,6 +1754,32 @@ namespace giac {
   static define_unary_function_eval (__split,&_split,_split_s);
   define_unary_function_ptr5( at_split ,alias_at_split,&__split,0,true);
  
+  gen _join(const gen & args,GIAC_CONTEXT){
+    if ( args.type==_STRNG && args.subtype==-1) return  args;
+    if (args.type==_VECT && args._VECTptr->size()==2){
+      gen g1=args._VECTptr->front(),g2=args._VECTptr->back();
+      if (g1.type==_STRNG && g2.type==_VECT){ // Python 
+	const_iterateur it=g2._VECTptr->begin(),itend=g2._VECTptr->end();
+	string res;
+	for (;it!=itend;){
+	  if (it->type==_STRNG)
+	    res += *it->_STRNGptr;
+	  else
+	    res += it->print(contextptr);
+	  ++it;
+	  if (it==itend)
+	    break;
+	  res += *g1._STRNGptr;
+	}
+	return string2gen(res,false);
+      }
+    }
+    return gensizeerr(contextptr);
+  } 
+  static const char _join_s[]="join";
+  static define_unary_function_eval (__join,&_join,_join_s);
+  define_unary_function_ptr5( at_join ,alias_at_join,&__join,0,true);
+ 
   gen _sum_riemann(const gen & args,GIAC_CONTEXT){
     if ( args.type==_STRNG && args.subtype==-1) return  args;
     //renvoie l'equivalent pour n=infini de sum de k=1 a n de g1 avec g2=[n,k])  
