@@ -395,7 +395,7 @@ namespace giac {
       if (!is_undef(a)){
 	if (x._VECTptr->size()==3 && a.type==_VECT){
 	  if (a._VECTptr->size()==1)
-	    return makemod(a._VECTptr->front(),p).print(contextptr);
+	    return '('+makemod(a._VECTptr->front(),p).print(contextptr)+')';
 	  gen tmp=symb_horner(*a._VECTptr,x._VECTptr->back());
 	  if (tmp.is_symb_of_sommet(at_plus))
 	    return '('+tmp.print(contextptr)+')';
@@ -739,7 +739,7 @@ namespace giac {
 	  vecteur2vector_int(*P._VECTptr,0,pmod);
 	  mulext(amod,bmod,pmod,m,ab);
 	  int absize=int(ab.size());
-	  int * i=&ab.front(),*iend=i+absize;
+	  int * i=ab.empty()?0:&ab.front(),*iend=i+absize;
 	  for (;i<iend;++i){
 	    int j=*i;
 	    //j =smod(j,m);
